# Installation

## Installing from PyPi

It is recommended that you use the latest version of python3 and pip for the installation of
earthkit-transforms.

```bash
pip install earthkit-transforms
```

To make use of the interoperable functionality you should ensure that you have installed the
*earthkit-data* dependancy.
